@@ -1,6 +1,6 @@
 from .console import Console
 from .const import DEFAULT_PYTHON_VERSION
 from .params import exclusive
-from .project import find_project_root
+from .project import find_project_root, get_project_settings
 from .run import run, run_node_command, run_poetry_command
 from .settings import get_standalone_settings_file
